@@ -1,13 +1,12 @@
-use crate::db::Rank;
-
-use anyhow::{bail, Context, Result};
-use dirs_next as dirs;
-use glob::Pattern;
-
 use std::env;
 use std::ffi::OsString;
 use std::path::PathBuf;
 
+use anyhow::{bail, Context, Result};
+use glob::Pattern;
+
+use crate::db::Rank;
+
 pub fn data_dir() -> Result<PathBuf> {
     let path = match env::var_os("_ZO_DATA_DIR") {
         Some(path) => PathBuf::from(path),
@@ -31,15 +30,8 @@ pub fn echo() -> bool {
 }
 
 pub fn exclude_dirs() -> Result<Vec<Pattern>> {
-    match env::var_os("_ZO_EXCLUDE_DIRS") {
-        Some(paths) => env::split_paths(&paths)
-            .map(|path| {
-                let pattern = path.to_str().context("invalid unicode in _ZO_EXCLUDE_DIRS")?;
-                Pattern::new(pattern)
-                    .with_context(|| format!("invalid glob in _ZO_EXCLUDE_DIRS: {}", pattern))
-            })
-            .collect(),
-        None => {
+    env::var_os("_ZO_EXCLUDE_DIRS").map_or_else(
+        || {
             let pattern = (|| {
                 let home = dirs::home_dir()?;
                 let home = home.to_str()?;
@@ -47,8 +39,16 @@ pub fn exclude_dirs() -> Result<Vec<Pattern>> {
                 Pattern::new(&home).ok()
             })();
             Ok(pattern.into_iter().collect())
-        }
-    }
+        },
+        |paths| {
+            env::split_paths(&paths)
+                .map(|path| {
+                    let pattern = path.to_str().context("invalid unicode in _ZO_EXCLUDE_DIRS")?;
+                    Pattern::new(pattern).with_context(|| format!("invalid glob in _ZO_EXCLUDE_DIRS: {}", pattern))
+                })
+                .collect()
+        },
+    )
 }
 
 pub fn fzf_opts() -> Option<OsString> {
@@ -59,9 +59,8 @@ pub fn maxage() -> Result<Rank> {
     match env::var_os("_ZO_MAXAGE") {
         Some(maxage) => {
             let maxage = maxage.to_str().context("invalid unicode in _ZO_MAXAGE")?;
-            let maxage = maxage
-                .parse::<u64>()
-                .with_context(|| format!("unable to parse _ZO_MAXAGE as integer: {}", maxage))?;
+            let maxage =
+                maxage.parse::<u64>().with_context(|| format!("unable to parse _ZO_MAXAGE as integer: {}", maxage))?;
             Ok(maxage as Rank)
         }
         None => Ok(10000.0),
